@@ -677,6 +677,15 @@ $(function() {
 		AddEditorTab();
 	});
 
+	$(".navbar .dropdown-menu li > a").click(function() {
+		var action = $(this).attr("id");
+		if(action) {
+			$(document).trigger(action);
+		} else {
+			alert("Undefined action. Please specify it as an id attribute!");
+		}
+	});
+
 	
 	$(document).on('action-close-file', function() {
 		
